Class: Kendama::Announcement

Inherits:
ApiModelBase show all
Defined in:
lib/kendama/models/announcement.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Announcement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/kendama/models/announcement.rb', line 190

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kendama::Announcement` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kendama::Announcement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'sequence_number')
    self.sequence_number = attributes[:'sequence_number']
  else
    self.sequence_number = nil
  end

  if attributes.key?(:'registrated_number')
    self.registrated_number = attributes[:'registrated_number']
  else
    self.registrated_number = nil
  end

  if attributes.key?(:'process')
    self.process = attributes[:'process']
  else
    self.process = nil
  end

  if attributes.key?(:'correct')
    self.correct = attributes[:'correct']
  else
    self.correct = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'latest')
    self.latest = attributes[:'latest']
  else
    self.latest = nil
  end

  if attributes.key?(:'registration_date')
    self.registration_date = attributes[:'registration_date']
  else
    self.registration_date = nil
  end

  if attributes.key?(:'update_date')
    self.update_date = attributes[:'update_date']
  else
    self.update_date = nil
  end

  if attributes.key?(:'disposal_date')
    self.disposal_date = attributes[:'disposal_date']
  else
    self.disposal_date = nil
  end

  if attributes.key?(:'expire_date')
    self.expire_date = attributes[:'expire_date']
  else
    self.expire_date = nil
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'address_prefecture_code')
    self.address_prefecture_code = attributes[:'address_prefecture_code']
  else
    self.address_prefecture_code = nil
  end

  if attributes.key?(:'address_city_code')
    self.address_city_code = attributes[:'address_city_code']
  else
    self.address_city_code = nil
  end

  if attributes.key?(:'address_request')
    self.address_request = attributes[:'address_request']
  else
    self.address_request = nil
  end

  if attributes.key?(:'address_request_prefecture_code')
    self.address_request_prefecture_code = attributes[:'address_request_prefecture_code']
  else
    self.address_request_prefecture_code = nil
  end

  if attributes.key?(:'address_request_city_code')
    self.address_request_city_code = attributes[:'address_request_city_code']
  else
    self.address_request_city_code = nil
  end

  if attributes.key?(:'kana')
    self.kana = attributes[:'kana']
  else
    self.kana = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'address_inside')
    self.address_inside = attributes[:'address_inside']
  else
    self.address_inside = nil
  end

  if attributes.key?(:'address_inside_prefecture_code')
    self.address_inside_prefecture_code = attributes[:'address_inside_prefecture_code']
  end

  if attributes.key?(:'address_inside_city_code')
    self.address_inside_city_code = attributes[:'address_inside_city_code']
  else
    self.address_inside_city_code = nil
  end

  if attributes.key?(:'trade_name')
    self.trade_name = attributes[:'trade_name']
  else
    self.trade_name = nil
  end

  if attributes.key?(:'popular_name_previous_name')
    self.popular_name_previous_name = attributes[:'popular_name_previous_name']
  else
    self.popular_name_previous_name = nil
  end
end

Instance Attribute Details

#addressObject

本店又は主たる事務所の所在地(法人)



52
53
54
# File 'lib/kendama/models/announcement.rb', line 52

def address
  @address
end

#address_city_codeObject

本店又は主たる事務所の所在地市区町村コード(法人)



58
59
60
# File 'lib/kendama/models/announcement.rb', line 58

def address_city_code
  @address_city_code
end

#address_insideObject

国内において行う資産の譲渡等に係る事務所、事業所その他これらに準ずるものの所在地



76
77
78
# File 'lib/kendama/models/announcement.rb', line 76

def address_inside
  @address_inside
end

#address_inside_city_codeObject

国内において行う資産の譲渡等に係る事務所、事業所その他これらに準ずるものの所在地市区町村コード



82
83
84
# File 'lib/kendama/models/announcement.rb', line 82

def address_inside_city_code
  @address_inside_city_code
end

#address_inside_prefecture_codeObject

国内において行う資産の譲渡等に係る事務所、事業所その他これらに準ずるものの所在地都道府県コード



79
80
81
# File 'lib/kendama/models/announcement.rb', line 79

def address_inside_prefecture_code
  @address_inside_prefecture_code
end

#address_prefecture_codeObject

本店又は主たる事務所の所在地都道府県コード(法人)



55
56
57
# File 'lib/kendama/models/announcement.rb', line 55

def address_prefecture_code
  @address_prefecture_code
end

#address_requestObject

本店又は主たる事務所の所在地(公表申出)



61
62
63
# File 'lib/kendama/models/announcement.rb', line 61

def address_request
  @address_request
end

#address_request_city_codeObject

本店又は主たる事務所の所在地市区町村コード(公表申出)



67
68
69
# File 'lib/kendama/models/announcement.rb', line 67

def address_request_city_code
  @address_request_city_code
end

#address_request_prefecture_codeObject

本店又は主たる事務所の所在地都道府県コード(公表申出)



64
65
66
# File 'lib/kendama/models/announcement.rb', line 64

def address_request_prefecture_code
  @address_request_prefecture_code
end

#correctObject

訂正区分



28
29
30
# File 'lib/kendama/models/announcement.rb', line 28

def correct
  @correct
end

#countryObject

国内外区分



34
35
36
# File 'lib/kendama/models/announcement.rb', line 34

def country
  @country
end

#disposal_dateObject

取消年月日



46
47
48
# File 'lib/kendama/models/announcement.rb', line 46

def disposal_date
  @disposal_date
end

#expire_dateObject

失効年月日



49
50
51
# File 'lib/kendama/models/announcement.rb', line 49

def expire_date
  @expire_date
end

#kanaObject

日本語(カナ)



70
71
72
# File 'lib/kendama/models/announcement.rb', line 70

def kana
  @kana
end

#kindObject

人格区分



31
32
33
# File 'lib/kendama/models/announcement.rb', line 31

def kind
  @kind
end

#latestObject

最新履歴



37
38
39
# File 'lib/kendama/models/announcement.rb', line 37

def latest
  @latest
end

#nameObject

氏名又は名称



73
74
75
# File 'lib/kendama/models/announcement.rb', line 73

def name
  @name
end

通称・旧姓



88
89
90
# File 'lib/kendama/models/announcement.rb', line 88

def popular_name_previous_name
  @popular_name_previous_name
end

#processObject

事業者処理区分



25
26
27
# File 'lib/kendama/models/announcement.rb', line 25

def process
  @process
end

#registrated_numberObject

登録番号



22
23
24
# File 'lib/kendama/models/announcement.rb', line 22

def registrated_number
  @registrated_number
end

#registration_dateObject

登録年月日



40
41
42
# File 'lib/kendama/models/announcement.rb', line 40

def registration_date
  @registration_date
end

#sequence_numberObject

一連番号



19
20
21
# File 'lib/kendama/models/announcement.rb', line 19

def sequence_number
  @sequence_number
end

#trade_nameObject

主たる屋号



85
86
87
# File 'lib/kendama/models/announcement.rb', line 85

def trade_name
  @trade_name
end

#update_dateObject

更新年月日



43
44
45
# File 'lib/kendama/models/announcement.rb', line 43

def update_date
  @update_date
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



143
144
145
# File 'lib/kendama/models/announcement.rb', line 143

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



148
149
150
# File 'lib/kendama/models/announcement.rb', line 148

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/kendama/models/announcement.rb', line 113

def self.attribute_map
  {
    :'sequence_number' => :'sequenceNumber',
    :'registrated_number' => :'registratedNumber',
    :'process' => :'process',
    :'correct' => :'correct',
    :'kind' => :'kind',
    :'country' => :'country',
    :'latest' => :'latest',
    :'registration_date' => :'registrationDate',
    :'update_date' => :'updateDate',
    :'disposal_date' => :'disposalDate',
    :'expire_date' => :'expireDate',
    :'address' => :'address',
    :'address_prefecture_code' => :'addressPrefectureCode',
    :'address_city_code' => :'addressCityCode',
    :'address_request' => :'addressRequest',
    :'address_request_prefecture_code' => :'addressRequestPrefectureCode',
    :'address_request_city_code' => :'addressRequestCityCode',
    :'kana' => :'kana',
    :'name' => :'name',
    :'address_inside' => :'addressInside',
    :'address_inside_prefecture_code' => :'addressInsidePrefectureCode',
    :'address_inside_city_code' => :'addressInsideCityCode',
    :'trade_name' => :'tradeName',
    :'popular_name_previous_name' => :'popularName_previousName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
# File 'lib/kendama/models/announcement.rb', line 844

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



183
184
185
186
# File 'lib/kendama/models/announcement.rb', line 183

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/kendama/models/announcement.rb', line 153

def self.openapi_types
  {
    :'sequence_number' => :'String',
    :'registrated_number' => :'String',
    :'process' => :'String',
    :'correct' => :'String',
    :'kind' => :'String',
    :'country' => :'String',
    :'latest' => :'String',
    :'registration_date' => :'Date',
    :'update_date' => :'Date',
    :'disposal_date' => :'String',
    :'expire_date' => :'String',
    :'address' => :'String',
    :'address_prefecture_code' => :'String',
    :'address_city_code' => :'String',
    :'address_request' => :'String',
    :'address_request_prefecture_code' => :'String',
    :'address_request_city_code' => :'String',
    :'kana' => :'String',
    :'name' => :'String',
    :'address_inside' => :'String',
    :'address_inside_prefecture_code' => :'String',
    :'address_inside_city_code' => :'String',
    :'trade_name' => :'String',
    :'popular_name_previous_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
# File 'lib/kendama/models/announcement.rb', line 800

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      sequence_number == o.sequence_number &&
      registrated_number == o.registrated_number &&
      process == o.process &&
      correct == o.correct &&
      kind == o.kind &&
      country == o.country &&
      latest == o.latest &&
      registration_date == o.registration_date &&
      update_date == o.update_date &&
      disposal_date == o.disposal_date &&
      expire_date == o.expire_date &&
      address == o.address &&
      address_prefecture_code == o.address_prefecture_code &&
      address_city_code == o.address_city_code &&
      address_request == o.address_request &&
      address_request_prefecture_code == o.address_request_prefecture_code &&
      address_request_city_code == o.address_request_city_code &&
      kana == o.kana &&
      name == o.name &&
      address_inside == o.address_inside &&
      address_inside_prefecture_code == o.address_inside_prefecture_code &&
      address_inside_city_code == o.address_inside_city_code &&
      trade_name == o.trade_name &&
      popular_name_previous_name == o.popular_name_previous_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


831
832
833
# File 'lib/kendama/models/announcement.rb', line 831

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



837
838
839
# File 'lib/kendama/models/announcement.rb', line 837

def hash
  [sequence_number, registrated_number, process, correct, kind, country, latest, registration_date, update_date, disposal_date, expire_date, address, address_prefecture_code, address_city_code, address_request, address_request_prefecture_code, address_request_city_code, kana, name, address_inside, address_inside_prefecture_code, address_inside_city_code, trade_name, popular_name_previous_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
# File 'lib/kendama/models/announcement.rb', line 349

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @sequence_number.nil?
    invalid_properties.push('invalid value for "sequence_number", sequence_number cannot be nil.')
  end

  if @sequence_number.to_s.length > 8
    invalid_properties.push('invalid value for "sequence_number", the character length must be smaller than or equal to 8.')
  end

  if @sequence_number.to_s.length < 1
    invalid_properties.push('invalid value for "sequence_number", the character length must be greater than or equal to 1.')
  end

  if @registrated_number.nil?
    invalid_properties.push('invalid value for "registrated_number", registrated_number cannot be nil.')
  end

  if @process.nil?
    invalid_properties.push('invalid value for "process", process cannot be nil.')
  end

  if @correct.nil?
    invalid_properties.push('invalid value for "correct", correct cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  if @latest.nil?
    invalid_properties.push('invalid value for "latest", latest cannot be nil.')
  end

  if @registration_date.nil?
    invalid_properties.push('invalid value for "registration_date", registration_date cannot be nil.')
  end

  if @update_date.nil?
    invalid_properties.push('invalid value for "update_date", update_date cannot be nil.')
  end

  if @disposal_date.nil?
    invalid_properties.push('invalid value for "disposal_date", disposal_date cannot be nil.')
  end

  if @expire_date.nil?
    invalid_properties.push('invalid value for "expire_date", expire_date cannot be nil.')
  end

  if @address.nil?
    invalid_properties.push('invalid value for "address", address cannot be nil.')
  end

  if @address.to_s.length > 600
    invalid_properties.push('invalid value for "address", the character length must be smaller than or equal to 600.')
  end

  if @address_prefecture_code.nil?
    invalid_properties.push('invalid value for "address_prefecture_code", address_prefecture_code cannot be nil.')
  end

  if @address_city_code.nil?
    invalid_properties.push('invalid value for "address_city_code", address_city_code cannot be nil.')
  end

  if @address_request.nil?
    invalid_properties.push('invalid value for "address_request", address_request cannot be nil.')
  end

  if @address_request.to_s.length > 600
    invalid_properties.push('invalid value for "address_request", the character length must be smaller than or equal to 600.')
  end

  if @address_request_prefecture_code.nil?
    invalid_properties.push('invalid value for "address_request_prefecture_code", address_request_prefecture_code cannot be nil.')
  end

  if @address_request_city_code.nil?
    invalid_properties.push('invalid value for "address_request_city_code", address_request_city_code cannot be nil.')
  end

  if @kana.nil?
    invalid_properties.push('invalid value for "kana", kana cannot be nil.')
  end

  if @kana.to_s.length > 500
    invalid_properties.push('invalid value for "kana", the character length must be smaller than or equal to 500.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 300
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 300.')
  end

  if @address_inside.nil?
    invalid_properties.push('invalid value for "address_inside", address_inside cannot be nil.')
  end

  if @address_inside.to_s.length > 300
    invalid_properties.push('invalid value for "address_inside", the character length must be smaller than or equal to 300.')
  end

  if @address_inside_city_code.nil?
    invalid_properties.push('invalid value for "address_inside_city_code", address_inside_city_code cannot be nil.')
  end

  if @trade_name.nil?
    invalid_properties.push('invalid value for "trade_name", trade_name cannot be nil.')
  end

  if @trade_name.to_s.length > 200
    invalid_properties.push('invalid value for "trade_name", the character length must be smaller than or equal to 200.')
  end

  if @popular_name_previous_name.nil?
    invalid_properties.push('invalid value for "popular_name_previous_name", popular_name_previous_name cannot be nil.')
  end

  if @popular_name_previous_name.to_s.length > 200
    invalid_properties.push('invalid value for "popular_name_previous_name", the character length must be smaller than or equal to 200.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



866
867
868
869
870
871
872
873
874
875
876
877
878
# File 'lib/kendama/models/announcement.rb', line 866

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'lib/kendama/models/announcement.rb', line 485

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @sequence_number.nil?
  return false if @sequence_number.to_s.length > 8
  return false if @sequence_number.to_s.length < 1
  return false if @registrated_number.nil?
  return false if @process.nil?
  process_validator = EnumAttributeValidator.new('String', ["01", "02", "03", "04", "99"])
  return false unless process_validator.valid?(@process)
  return false if @correct.nil?
  correct_validator = EnumAttributeValidator.new('String', ["0", "1", ""])
  return false unless correct_validator.valid?(@correct)
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["1", "2"])
  return false unless kind_validator.valid?(@kind)
  return false if @country.nil?
  country_validator = EnumAttributeValidator.new('String', ["1", "2", "3"])
  return false unless country_validator.valid?(@country)
  return false if @latest.nil?
  latest_validator = EnumAttributeValidator.new('String', ["0", "1"])
  return false unless latest_validator.valid?(@latest)
  return false if @registration_date.nil?
  return false if @update_date.nil?
  return false if @disposal_date.nil?
  return false if @expire_date.nil?
  return false if @address.nil?
  return false if @address.to_s.length > 600
  return false if @address_prefecture_code.nil?
  return false if @address_city_code.nil?
  return false if @address_request.nil?
  return false if @address_request.to_s.length > 600
  return false if @address_request_prefecture_code.nil?
  return false if @address_request_city_code.nil?
  return false if @kana.nil?
  return false if @kana.to_s.length > 500
  return false if @name.nil?
  return false if @name.to_s.length > 300
  return false if @address_inside.nil?
  return false if @address_inside.to_s.length > 300
  return false if @address_inside_city_code.nil?
  return false if @trade_name.nil?
  return false if @trade_name.to_s.length > 200
  return false if @popular_name_previous_name.nil?
  return false if @popular_name_previous_name.to_s.length > 200
  true
end