Class: Kendama::ResponseBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Kendama::ResponseBody
- Defined in:
- lib/kendama/models/response_body.rb
Instance Attribute Summary collapse
-
#announcement ⇒ Object
Returns the value of attribute announcement.
-
#count ⇒ Object
総件数.
-
#divide_number ⇒ Object
分割番号.
-
#divide_size ⇒ Object
分割数.
-
#last_update_date ⇒ Object
最終更新年月日.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResponseBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ResponseBody
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/kendama/models/response_body.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kendama::ResponseBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kendama::ResponseBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'last_update_date') self.last_update_date = attributes[:'last_update_date'] end if attributes.key?(:'count') self.count = attributes[:'count'] end if attributes.key?(:'divide_number') self.divide_number = attributes[:'divide_number'] end if attributes.key?(:'divide_size') self.divide_size = attributes[:'divide_size'] end if attributes.key?(:'announcement') if (value = attributes[:'announcement']).is_a?(Array) self.announcement = value end end end |
Instance Attribute Details
#announcement ⇒ Object
Returns the value of attribute announcement.
30 31 32 |
# File 'lib/kendama/models/response_body.rb', line 30 def announcement @announcement end |
#count ⇒ Object
総件数
22 23 24 |
# File 'lib/kendama/models/response_body.rb', line 22 def count @count end |
#divide_number ⇒ Object
分割番号
25 26 27 |
# File 'lib/kendama/models/response_body.rb', line 25 def divide_number @divide_number end |
#divide_size ⇒ Object
分割数
28 29 30 |
# File 'lib/kendama/models/response_body.rb', line 28 def divide_size @divide_size end |
#last_update_date ⇒ Object
最終更新年月日
19 20 21 |
# File 'lib/kendama/models/response_body.rb', line 19 def last_update_date @last_update_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/kendama/models/response_body.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/kendama/models/response_body.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/kendama/models/response_body.rb', line 33 def self.attribute_map { :'last_update_date' => :'lastUpdateDate', :'count' => :'count', :'divide_number' => :'divideNumber', :'divide_size' => :'divideSize', :'announcement' => :'announcement' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/kendama/models/response_body.rb', line 235 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/kendama/models/response_body.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/kendama/models/response_body.rb', line 54 def self.openapi_types { :'last_update_date' => :'Date', :'count' => :'String', :'divide_number' => :'String', :'divide_size' => :'String', :'announcement' => :'Array<Announcement>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 |
# File 'lib/kendama/models/response_body.rb', line 210 def ==(o) return true if self.equal?(o) self.class == o.class && last_update_date == o.last_update_date && count == o.count && divide_number == o.divide_number && divide_size == o.divide_size && announcement == o.announcement end |
#eql?(o) ⇒ Boolean
222 223 224 |
# File 'lib/kendama/models/response_body.rb', line 222 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/kendama/models/response_body.rb', line 228 def hash [last_update_date, count, divide_number, divide_size, announcement].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/kendama/models/response_body.rb', line 111 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@count.nil? && @count.to_s.length > 8 invalid_properties.push('invalid value for "count", the character length must be smaller than or equal to 8.') end if !@count.nil? && @count.to_s.length < 1 invalid_properties.push('invalid value for "count", the character length must be greater than or equal to 1.') end if !@divide_number.nil? && @divide_number.to_s.length > 6 invalid_properties.push('invalid value for "divide_number", the character length must be smaller than or equal to 6.') end if !@divide_number.nil? && @divide_number.to_s.length < 1 invalid_properties.push('invalid value for "divide_number", the character length must be greater than or equal to 1.') end if !@divide_size.nil? && @divide_size.to_s.length > 6 invalid_properties.push('invalid value for "divide_size", the character length must be smaller than or equal to 6.') end if !@divide_size.nil? && @divide_size.to_s.length < 1 invalid_properties.push('invalid value for "divide_size", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/kendama/models/response_body.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 148 149 150 151 152 |
# File 'lib/kendama/models/response_body.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@count.nil? && @count.to_s.length > 8 return false if !@count.nil? && @count.to_s.length < 1 return false if !@divide_number.nil? && @divide_number.to_s.length > 6 return false if !@divide_number.nil? && @divide_number.to_s.length < 1 return false if !@divide_size.nil? && @divide_size.to_s.length > 6 return false if !@divide_size.nil? && @divide_size.to_s.length < 1 true end |